Enum Event
#[non_exhaustive]pub enum Event {
SupportedIntent {
render_intent: WEnum<RenderIntent>,
},
SupportedFeature {
feature: WEnum<Feature>,
},
SupportedTfNamed {
tf: WEnum<TransferFunction>,
},
SupportedPrimariesNamed {
primaries: WEnum<Primaries>,
},
Done,
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
SupportedIntent
supported rendering intent
When this object is created, it shall immediately send this event once for each rendering intent the compositor supports.
A compositor must not advertise intents that are deprecated in the bound version of the interface.
Fields
render_intent: WEnum<RenderIntent>rendering intent
SupportedFeature
supported features
When this object is created, it shall immediately send this event once for each compositor supported feature listed in the enumeration.
A compositor must not advertise features that are deprecated in the bound version of the interface.
SupportedTfNamed
supported named transfer characteristic
When this object is created, it shall immediately send this event once for each named transfer function the compositor supports with the parametric image description creator.
A compositor must not advertise transfer functions that are deprecated in the bound version of the interface.
Fields
tf: WEnum<TransferFunction>Named transfer function
SupportedPrimariesNamed
supported named primaries
When this object is created, it shall immediately send this event once for each named set of primaries the compositor supports with the parametric image description creator.
A compositor must not advertise names that are deprecated in the bound version of the interface.
Done
all features have been sent
This event is sent when all supported rendering intents, features, transfer functions and named primaries have been sent.
Implementations