Enum Primaries
#[non_exhaustive]#[repr(u32)]pub enum Primaries {
Srgb = 1,
PalM = 2,
Pal = 3,
Ntsc = 4,
GenericFilm = 5,
Bt2020 = 6,
Cie1931Xyz = 7,
DciP3 = 8,
DisplayP3 = 9,
AdobeRgb = 10,
}wayland and Linux only.Expand description
named color primaries
Named color primaries used to encode well-known sets of primaries.
A value of 0 is invalid and will never be present in the list of enums.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Srgb = 1
Color primaries for the sRGB color space as defined by the BT.709 standard
Color primaries as defined by
- Rec. ITU-R BT.709-6
- Rec. ITU-R BT.1361-0 conventional colour gamut system and extended colour gamut system (historical)
- IEC 61966-2-1 sRGB or sYCC
- IEC 61966-2-4
- Society of Motion Picture and Television Engineers (SMPTE) RP 177 (1993) Annex B
PalM = 2
Color primaries for PAL-M as defined by the BT.470 standard
Color primaries as defined by
- Rec. ITU-R BT.470-6 System M (historical)
- United States National Television System Committee 1953 Recommendation for transmission standards for color television
- United States Federal Communications Commission (2003) Title 47 Code of Federal Regulations 73.682 (a)(20)
Pal = 3
Color primaries for PAL as defined by the BT.601 standard
Color primaries as defined by
- Rec. ITU-R BT.470-6 System B, G (historical)
- Rec. ITU-R BT.601-7 625
- Rec. ITU-R BT.1358-0 625 (historical)
- Rec. ITU-R BT.1700-0 625 PAL and 625 SECAM
Ntsc = 4
Color primaries for NTSC as defined by the BT.601 standard
Color primaries as defined by
- Rec. ITU-R BT.601-7 525
- Rec. ITU-R BT.1358-1 525 or 625 (historical)
- Rec. ITU-R BT.1700-0 NTSC
- SMPTE 170M (2004)
- SMPTE 240M (1999) (historical)
GenericFilm = 5
Generic film with colour filters using Illuminant C
Color primaries as defined by Recommendation ITU-T H.273 “Coding-independent code points for video signal type identification” for “generic film”.
Bt2020 = 6
Color primaries as defined by the BT.2020 and BT.2100 standard
Color primaries as defined by
- Rec. ITU-R BT.2020-2
- Rec. ITU-R BT.2100-0
Cie1931Xyz = 7
Color primaries of the full CIE 1931 XYZ color space
Color primaries as defined as the maximum of the CIE 1931 XYZ color space by
- SMPTE ST 428-1
- (CIE 1931 XYZ as in ISO 11664-1)
DciP3 = 8
Color primaries of the DCI P3 color space as defined by the SMPTE RP 431 standard
Color primaries as defined by Digital Cinema System and published in SMPTE RP 431-2 (2011).
DisplayP3 = 9
Color primaries of Display P3 variant of the DCI-P3 color space as defined by the SMPTE EG 432 standard
Color primaries as defined by Digital Cinema System and published in SMPTE EG 432-1 (2010).
AdobeRgb = 10
Color primaries of the Adobe RGB color space as defined by the ISO 12640 standard
Color primaries as defined by Adobe as “Adobe RGB” and later published by ISO 12640-4 (2011).