Enum RenderIntent
#[non_exhaustive]#[repr(u32)]pub enum RenderIntent {
Perceptual = 0,
Relative = 1,
Saturation = 2,
Absolute = 3,
RelativeBpc = 4,
AbsoluteNoAdaptation = 5,
}wayland and Linux only.Expand description
rendering intents
See the ICC.1:2022 specification from the International Color Consortium for more details about rendering intents.
The principles of ICC defined rendering intents apply with all types of image descriptions, not only those with ICC file profiles.
Compositors must support the perceptual rendering intent. Other rendering intents are optional.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Perceptual = 0
perceptual
Relative = 1
media-relative colorimetric
Saturation = 2
saturation
Absolute = 3
ICC-absolute colorimetric
RelativeBpc = 4
media-relative colorimetric + black point compensation
AbsoluteNoAdaptation = 5
ICC-absolute colorimetric without adaptation
This rendering intent is a modified absolute rendering intent that assumes the viewer is not adapted to the display white point, so no chromatic adaptation between surface and display is done. This can be useful for color proofing applications.