Enum TransferFunction
#[non_exhaustive]#[repr(u32)]pub enum TransferFunction {
Show 14 variants
Bt1886 = 1,
Gamma22 = 2,
Gamma28 = 3,
St240 = 4,
ExtLinear = 5,
Log100 = 6,
Log316 = 7,
Xvycc = 8,
Srgb = 9,
ExtSrgb = 10,
St2084Pq = 11,
St428 = 12,
Hlg = 13,
CompoundPower24 = 14,
}wayland and Linux only.Expand description
named transfer functions
Named transfer functions used to represent well-known transfer characteristics of displays.
A value of 0 is invalid and will never be present in the list of enums.
See appendix.md for the formulae.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Bt1886 = 1
BT.1886 display transfer characteristic
Rec. ITU-R BT.1886 is the display transfer characteristic assumed by
- Rec. ITU-R BT.601-7 525 and 625
- Rec. ITU-R BT.709-6
- Rec. ITU-R BT.2020-2
This TF implies these default luminances from Rec. ITU-R BT.2035:
- primary color volume minimum: 0.01 cd/m²
- primary color volume maximum: 100 cd/m²
- reference white: 100 cd/m²
Gamma22 = 2
Assumed display gamma 2.2 transfer function
Transfer characteristics as defined by
- Rec. ITU-R BT.470-6 System M (historical)
- United States National Television System Committee 1953 Recommendation for transmission standards for color television
- United States Federal Communications Commission (2003) Title 47 Code of Federal Regulations 73.682 (a) (20)
- Rec. ITU-R BT.1700-0 625 PAL and 625 SECAM
- IEC 61966-2-1 (reference display)
Gamma28 = 3
Assumed display gamma 2.8 transfer function
Transfer characteristics as defined by
- Rec. ITU-R BT.470-6 System B, G (historical)
St240 = 4
SMPTE ST 240 transfer function
Transfer characteristics as defined by
- SMPTE ST 240 (1999)
ExtLinear = 5
extended linear transfer function
Linear transfer function defined over all real numbers. Normalised electrical values are equal the normalised optical values.
Log100 = 6
logarithmic 100:1 transfer function
Logarithmic transfer characteristic (100:1 range).
Log316 = 7
logarithmic (100*Sqrt(10) : 1) transfer function
Logarithmic transfer characteristic (100 * Sqrt(10) : 1 range).
Xvycc = 8
IEC 61966-2-4 transfer function
Transfer characteristics as defined by
- IEC 61966-2-4
Srgb = 9
Deprecated (ambiguous sRGB transfer function)
Transfer characteristics as defined by
- IEC 61966-2-1 sRGB
As a rule of thumb, use gamma22 for video, motion picture and computer graphics, or compound_power_2_4 for ICC calibrated print workflows.
ExtSrgb = 10
Deprecated (Extended sRGB piece-wise transfer function)
Transfer characteristics as defined by
- IEC 61966-2-1 sYCC
St2084Pq = 11
perceptual quantizer transfer function
Transfer characteristics as defined by
- SMPTE ST 2084 (2014) for 10-, 12-, 14- and 16-bit systems
- Rec. ITU-R BT.2100-2 perceptual quantization (PQ) system
This TF implies these default luminances
- primary color volume minimum: 0.005 cd/m²
- primary color volume maximum: 10000 cd/m²
- reference white: 203 cd/m²
The difference between the primary color volume minimum and maximum must be approximately 10000 cd/m² as that is the swing of the EOTF defined by ST 2084 and BT.2100. The default value for the reference white is a protocol addition: it is suggested by Report ITU-R BT.2408-7 and is not part of ST 2084 or BT.2100.
St428 = 12
SMPTE ST 428 transfer function
Transfer characteristics as defined by
- SMPTE ST 428-1 (2019)
Hlg = 13
hybrid log-gamma transfer function
Transfer characteristics as defined by
- ARIB STD-B67 (2015)
- Rec. ITU-R BT.2100-2 hybrid log-gamma (HLG) system
This TF implies these default luminances
- primary color volume minimum: 0.005 cd/m²
- primary color volume maximum: 1000 cd/m²
- reference white: 203 cd/m²
HLG is a relative display-referred signal with a specified non-linear mapping to the display peak luminance (the HLG OOTF). All absolute luminance values used here for HLG assume a 1000 cd/m² peak display.
The default value for the reference white is a protocol addition: it is suggested by Report ITU-R BT.2408-7 and is not part of ARIB STD-B67 or BT.2100.
CompoundPower24 = 14
IEC 61966-2-1 encoding function
Encoding characteristics as defined by IEC 61966-2-1, for displays that invert the encoding function.