Struct WpColorManagerV1

pub struct WpColorManagerV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
color manager singleton

A singleton global interface used for getting color management extensions for wl_surface and wl_output objects, and for creating client defined image description objects. The extension interfaces allow getting the image description of outputs and setting the image description of surfaces.

Compositors should never remove this global.

See also the Event enum for this interface.

Implementations



impl WpColorManagerV1

pub fn destroy(&self)

destroy the color manager

Destroy the wp_color_manager_v1 object. This does not affect any other objects in any way.

pub fn get_output<U, D>( &self, output: &WlOutput, qh: &QueueHandle<D>, udata: U, ) -> WpColorManagementOutputV1
where U: Send + Sync + 'static, D: Dispatch<WpColorManagementOutputV1, U> + 'static,

create a color management interface for a wl_output

This creates a new wp_color_management_output_v1 object for the given wl_output.

See the wp_color_management_output_v1 interface for more details.

pub fn get_surface<U, D>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> WpColorManagementSurfaceV1
where U: Send + Sync + 'static, D: Dispatch<WpColorManagementSurfaceV1, U> + 'static,

create a color management interface for a wl_surface

If a wp_color_management_surface_v1 object already exists for the given wl_surface, the protocol error surface_exists is raised.

This creates a new color wp_color_management_surface_v1 object for the given wl_surface.

See the wp_color_management_surface_v1 interface for more details.

pub fn get_surface_feedback<U, D>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> WpColorManagementSurfaceFeedbackV1
where U: Send + Sync + 'static, D: Dispatch<WpColorManagementSurfaceFeedbackV1, U> + 'static,

create a color management feedback interface

This creates a new color wp_color_management_surface_feedback_v1 object for the given wl_surface.

See the wp_color_management_surface_feedback_v1 interface for more details.

pub fn create_icc_creator<U, D>( &self, qh: &QueueHandle<D>, udata: U, ) -> WpImageDescriptionCreatorIccV1
where U: Send + Sync + 'static, D: Dispatch<WpImageDescriptionCreatorIccV1, U> + 'static,

make a new ICC-based image description creator object

Makes a new ICC-based image description creator object with all properties initially unset. The client can then use the object’s interface to define all the required properties for an image description and finally create a wp_image_description_v1 object.

This request can be used when the compositor advertises wp_color_manager_v1.feature.icc_v2_v4. Otherwise this request raises the protocol error unsupported_feature.

pub fn create_parametric_creator<U, D>( &self, qh: &QueueHandle<D>, udata: U, ) -> WpImageDescriptionCreatorParamsV1
where U: Send + Sync + 'static, D: Dispatch<WpImageDescriptionCreatorParamsV1, U> + 'static,

make a new parametric image description creator object

Makes a new parametric image description creator object with all properties initially unset. The client can then use the object’s interface to define all the required properties for an image description and finally create a wp_image_description_v1 object.

This request can be used when the compositor advertises wp_color_manager_v1.feature.parametric. Otherwise this request raises the protocol error unsupported_feature.

pub fn create_windows_scrgb<U, D>( &self, qh: &QueueHandle<D>, udata: U, ) -> WpImageDescriptionV1
where U: Send + Sync + 'static, D: Dispatch<WpImageDescriptionV1, U> + 'static,

create Windows-scRGB image description object

This creates a pre-defined image description for the so-called Windows-scRGB stimulus encoding. This comes from the Windows 10 handling of its own definition of an scRGB color space for an HDR screen driven in BT.2100/PQ signalling mode.

Windows-scRGB uses sRGB (BT.709) color primaries and white point. The transfer characteristic is extended linear.

The nominal color channel value range is extended, meaning it includes negative and greater than 1.0 values. Negative values are used to escape the sRGB color gamut boundaries. To make use of the extended range, the client needs to use a pixel format that can represent those values, e.g. floating-point 16 bits per channel.

Nominal color value R=G=B=0.0 corresponds to BT.2100/PQ system 0 cd/m², and R=G=B=1.0 corresponds to BT.2100/PQ system 80 cd/m². The maximum is R=G=B=125.0 corresponding to 10k cd/m².

Windows-scRGB is displayed by Windows 10 by converting it to BT.2100/PQ, maintaining the CIE 1931 chromaticity and mapping the luminance as above. No adjustment is made to the signal to account for the viewing conditions.

The reference white level of Windows-scRGB is unknown. If a reference white level must be assumed for compositor processing, it should be R=G=B=2.5375 corresponding to 203 cd/m² of Report ITU-R BT.2408-7.

The target color volume of Windows-scRGB is unknown. The color gamut may be anything between sRGB and BT.2100.

Note: EGL_EXT_gl_colorspace_scrgb_linear definition differs from Windows-scRGB by using R=G=B=1.0 as the reference white level, while Windows-scRGB reference white level is unknown or varies. However, it seems probable that Windows implements both EGL_EXT_gl_colorspace_scrgb_linear and Vulkan VK_COLOR_SPACE_EXTENDED_SRGB_LINEAR_EXT as Windows-scRGB.

This request can be used when the compositor advertises wp_color_manager_v1.feature.windows_scrgb. Otherwise this request raises the protocol error unsupported_feature.

The resulting image description object does not allow get_information request. The wp_image_description_v1.ready event shall be sent.

pub fn get_image_description<U, D>( &self, reference: &WpImageDescriptionReferenceV1, qh: &QueueHandle<D>, udata: U, ) -> WpImageDescriptionV1
where U: Send + Sync + 'static, D: Dispatch<WpImageDescriptionV1, U> + 'static,

create an image description from a reference

This request retrieves the image description backing a reference.

The get_information request can be used if and only if the request that creates the reference allows it.